@@ -11,6 +11,8 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(:all);
 use namespace::clean;
 
+=encoding utf8
+
 =head1 NAME
 
 Data::Transpose - iterate, filter and validate data, and transpose to
@@ -24,11 +26,11 @@ transposing to different field names.
 
 =head1 VERSION
 
-Version 0.0022
+Version 0.0023
 
 =cut
 
-our $VERSION = '0.0022';
+our $VERSION = '0.0023';
 
 =head1 SYNOPSIS
 
@@ -299,8 +301,12 @@ L<http://search.cpan.org/dist/Data-Transpose/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Todd Wade for mxcheck test failures fix (GH #5, #11)
-and improvements to documentation (GH #12, #13).
+Peter Mottram (GH #19, #28).
+Lisa Hare (GH #27).
+Marco Pessotto (GH #6, #7, #14, #24, #26).
+Slaven Rezić (GH #25).
+Sam Batschelet (GH #16, #18).
+Todd Wade (GH #5, #11, #12, #13).
 
 =head1 LICENSE AND COPYRIGHT
 
