@@ -195,8 +195,7 @@ sub test_cc_numbers {
                                 ],
 
 
-                "Discover card" => [ '30569309025904',
-                                     '38520000023237',  
+                "Discover card" => [
                                      '6011111111111117',
                                      '6011000990139424',
 
